api.authentication.v1.sms package — Argus-Toolbelt 1.0 documentation

# api.authentication.v1.sms package

## Submodules

## api.authentication.v1.sms.sms_authenticate module

Autogenerated API

`api.authentication.v1.sms.sms_authenticate.` `authenticate`(userName: str = None, domain: str = None, mode: str = None, passcode: str = None, cookie: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Initiate a new user session using SMS authentication (PUBLIC) Requires SMS authentication to be enabled on the server, and for the user. Use /methods to check which authentication methods are available on the server.

  This is a 2-step authentication method. The first request should have mode PASSWORD, and carry username and static password. The request will return a challenge, carrying a session cookie.When the SMS code is received, submit a new request with mode VERIFICATION, the username, SMS code (in the passcode) and the session cookie returned in the challenge.

  Return type: | `dict`

## Module contents